## Fix Denied — Please Provide Feedback

The automated fix was rejected. To help Claude generate a better fix, please fill in the details below.

### What went wrong with the fix?

<!-- Describe what the fix got wrong — incorrect logic, wrong file, missing edge case, etc. -->

### What is the expected behavior?

<!-- Describe what the correct fix should do instead. -->

### Additional context or logs

<!-- Paste any relevant logs, stack traces, or screenshots that would help. -->

---

> [!NOTE]
> The issue has been reset to `claude-diagnosed`. After adding feedback above, reply `@claude acknowledge` to accept the updated diagnosis, then `@claude continue` to generate a new fix.
